"use strict";
const dom_1 = require("../dom");
var Style;
(function (Style) {
    Style[Style["Any"] = 0] = "Any";
    Style[Style["AlwaysOmit"] = 1] = "AlwaysOmit";
    Style[Style["AlwaysSelfclose"] = 2] = "AlwaysSelfclose";
})(Style || (Style = {}));
function init(parser, userOptions) {
    const options = Object.assign({}, this.defaults, userOptions);
    const style = parseStyle(options.style);
    parser.on('tag:close', (event, report) => {
        const current = event.target;
        const active = event.previous;
        if (current && current.meta) {
            validateCurrent(current, report);
        }
        if (active && active.meta) {
            validateActive(active, report);
        }
    });
    function validateCurrent(node, report) {
        if (node.voidElement && node.closed === dom_1.NodeClosed.EndTag) {
            report(node, `End tag for <${node.tagName}> must be omitted`);
        }
    }
    function validateActive(node, report) {
        const selfOrOmitted = node.closed === dom_1.NodeClosed.Omitted || node.closed === dom_1.NodeClosed.Self;
        if (node.voidElement) {
            if (style === Style.AlwaysOmit && node.closed === dom_1.NodeClosed.Self) {
                report(node, `Expected omitted end tag <${node.tagName}> instead of self-closing element <${node.tagName}/>`);
            }
            if (style === Style.AlwaysSelfclose && node.closed === dom_1.NodeClosed.Omitted) {
                report(node, `Expected self-closing element <${node.tagName}/> instead of omitted end-tag <${node.tagName}>`);
            }
        }
        if (selfOrOmitted && node.voidElement === false) {
            report(node, `End tag for <${node.tagName}> must not be omitted`);
        }
    }
}
function parseStyle(name) {
    switch (name) {
        case 'any': return Style.Any;
        case 'omit': return Style.AlwaysOmit;
        case 'selfclose': return Style.AlwaysSelfclose;
        default: return Style.Any;
    }
}
module.exports = {
    name: 'void',
    init,
    defaults: {
        style: 'omit',
    },
};
